@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..40\n"; }
+BEGIN { $| = 1; print "1..44\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Data::Table;
 $loaded = 1;
@@ -226,17 +226,38 @@ if ($t->tsv eq $t2->tsv) {
   print "not ok 38 fromTSV and tsv\n";
 }
 
-$t2=Data::Table::fromCSV('aaa.csv');
-if (equal($t->rowRefs(), $t2->rowRefs())) {
-  print "ok 39 overall\n";
+$t2 = $t->rowHashRef(1);
+if (scalar keys(%$t2) == $t->nofCol) {
+  print "ok 39 rowHashRef\n";
 } else {
-  print "not ok 39 overall\n";
+  print "not ok 39 rowHashRef\n";
 }
 
+$t2=Data::Table::fromCSV('aaa.csv');
+if (equal($t->rowRefs(), $t2->rowRefs())) {
+  print "ok 40 looks good so far\n";
+} else {
+  print "not ok 40 something broke already\n";
+}
+
+$t = Data::Table->fromCSVi("aaa.csv");
+if (equal($t->rowRefs(), $t2->rowRefs())) {
+  print "ok 41 instant method fromCSVi\n";
+} else {
+  print "not ok 41 instant method fromCSVi\n";
+}
+$t = Data::Table->fromTSVi("aaa.tsv");
+if (equal($t->rowRefs(), $t2->rowRefs())) {
+  print "ok 42 instant method fromTSVi\n";
+} else {
+  print "not ok 42 instant method fromTSVi\n";
+}
 # use DBI;
 # $dbh= DBI->connect("DBI:mysql:test", "test", "") or die $dbh->errstr;
 # $t = Data::Table::fromSQL($dbh, "show tables");
 # print $t->csv;
+# $t = Data::Table->fromSQLi($dbh, "show tables");
+# print $t->csv;
 
 # @_ in match_
 package FOO; @ISA = qw(Data::Table);
@@ -245,11 +266,17 @@ package FOO; @ISA = qw(Data::Table);
 
 package main;
 
-$foo=new FOO([[11,12],[21,22],[31,32]],['header1','header2'],0);
+$foo=FOO->new([[11,12],[21,22],[31,32]],['header1','header2'],0);
 if ($foo->csv) {
-  print "ok 40 Inheritance\n";
+  print "ok 43 Inheritance\n";
 } else {
-  print "not ok 40 Inheritance\n";
+  print "not ok 43 Inheritance\n";
+}
+$foo = FOO->fromCSVi("aaa.csv");
+if ($foo->csv) {
+  print "ok 44 inheritated instant method fromCSVi\n";
+} else {
+  print "not ok 44 inheritated instant method fromCSVi\n";
 }
 
 sub equal {
